# Commands

## Core Commands (v0.4.0)

- [oasr](ROOT.md) - Global flags and options
- [oasr registry](REGISTRY.md) - Manage skill registry (validate, add, remove, list, sync, prune)
- [oasr diff](DIFF.md) - Show status of tracked skills
- [oasr sync](SYNC.md) - Refresh outdated tracked skills
- [oasr config](CONFIG.md) - Manage configuration (NEW in v0.4.0)
- [oasr clone](CLONE.md) - Clone skill(s) to target directory (NEW in v0.4.0)
- [oasr exec](EXEC.md) - Execute skills as CLI tools (NEW in v0.4.0)
- [oasr find](FIND.md) - Find/discover skills in your file system
- [oasr validate](VALIDATE.md) - Validate a skill
- [oasr adapter](ADAPTER.md) - Generate IDE/Tooling adapters
- [oasr update](UPDATE.md) - Update the `oasr` CLI
- [oasr info](INFO.md) - Show detailed information about a skill
- [oasr help](HELP.md) - Show the help menu

## Deprecated Commands

### v0.4.1 Deprecations
- [oasr clean](CLEAN.md) - **Deprecated**, use `oasr registry prune` instead (will be removed in v0.6.0)

### v0.4.0 Deprecations
- [oasr use](USE.md) - **Deprecated**, use `oasr clone` instead (will be removed in v0.5.0)

### v0.3.0 Reorganization
These commands were reorganized in v0.3.0:
- [oasr add](ADD.md) - **Moved to** `oasr registry add`
- [oasr list](LIST.md) - **Moved to** `oasr registry list`
- [oasr rm](RM.md) - **Moved to** `oasr registry rm`
- [oasr status](STATUS.md) - **Replaced by** `oasr registry -v` and `oasr diff`
